==> eam-wshub-proxyclient-11.4-5-sources.jar: net/datastream/schemas/mp_fields/INTERFACEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour INTERFACEDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="INTERFACEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERFACETYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPLOADCOLUMN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INTERFACEDETAILS_Type", propOrder = {
    "interfacetype",
    "groupsequence",
    "uploadcolumn",
    "action"
})
public class INTERFACEDETAILS_Type {

    @XmlElement(name = "INTERFACETYPE", required = true)
    protected String interfacetype;
    @XmlElement(name = "GROUPSEQUENCE")
    protected Long groupsequence;
    @XmlElement(name = "UPLOADCOLUMN", required = true)
    protected String uploadcolumn;
    @XmlElement(name = "ACTION", required = true)
    protected String action;

    /**
     * Obtient la valeur de la propriété interfacetype.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTERFACETYPE() {
        return interfacetype;
    }

    /**
     * Définit la valeur de la propriété interfacetype.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTERFACETYPE(String value) {
        this.interfacetype = value;
    }

    /**
     * Obtient la valeur de la propriété groupsequence.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGROUPSEQUENCE() {
        return groupsequence;
    }

    /**
     * Définit la valeur de la propriété groupsequence.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGROUPSEQUENCE(Long value) {
        this.groupsequence = value;
    }

    /**
     * Obtient la valeur de la propriété uploadcolumn.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUPLOADCOLUMN() {
        return uploadcolumn;
    }

    /**
     * Définit la valeur de la propriété uploadcolumn.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUPLOADCOLUMN(String value) {
        this.uploadcolumn = value;
    }

    /**
     * Obtient la valeur de la propriété action.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTION() {
        return action;
    }

    /**
     * Définit la valeur de la propriété action.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTION(String value) {
        this.action = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/INTERFACEDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for INTERFACEDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="INTERFACEDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}INTERFACETYPE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}GROUPSEQUENCE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}UPLOADCOLUMN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ACTION"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "INTERFACEDETAILS_Type", propOrder = {
    "interfacetype",
    "groupsequence",
    "uploadcolumn",
    "action"
})
public class INTERFACEDETAILS_Type {

    @XmlElement(name = "INTERFACETYPE", required = true)
    protected String interfacetype;
    @XmlElement(name = "GROUPSEQUENCE")
    protected Long groupsequence;
    @XmlElement(name = "UPLOADCOLUMN", required = true)
    protected String uploadcolumn;
    @XmlElement(name = "ACTION", required = true)
    protected String action;

    /**
     * Gets the value of the interfacetype property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getINTERFACETYPE() {
        return interfacetype;
    }

    /**
     * Sets the value of the interfacetype property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setINTERFACETYPE(String value) {
        this.interfacetype = value;
    }

    /**
     * Gets the value of the groupsequence property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getGROUPSEQUENCE() {
        return groupsequence;
    }

    /**
     * Sets the value of the groupsequence property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setGROUPSEQUENCE(Long value) {
        this.groupsequence = value;
    }

    /**
     * Gets the value of the uploadcolumn property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getUPLOADCOLUMN() {
        return uploadcolumn;
    }

    /**
     * Sets the value of the uploadcolumn property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setUPLOADCOLUMN(String value) {
        this.uploadcolumn = value;
    }

    /**
     * Gets the value of the action property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getACTION() {
        return action;
    }

    /**
     * Sets the value of the action property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setACTION(String value) {
        this.action = value;
    }

}
